use crate::extractors::client_auth::APIClientAuth;
use crate::server::HttpResult;
use actix_web::{web, HttpResponse};
use ruma::api::client::state;
use ruma::events::StateEventType;
use ruma::OwnedRoomId;

#[derive(serde::Deserialize)]
pub struct RoomIDInPath {
    room_id: OwnedRoomId,
}

#[derive(serde::Serialize)]
struct GetRoomNameResponse {
    name: String,
}

/// Get room name
pub async fn name(auth: APIClientAuth, path: web::Path<RoomIDInPath>) -> HttpResult {
    let res = auth
        .send_request(state::get_state_events_for_key::v3::Request::new(
            path.room_id.clone(),
            StateEventType::RoomName,
            String::default(),
        ))
        .await?;

    Ok(HttpResponse::Ok().json(GetRoomNameResponse {
        name: res.content.get_field("name")?.unwrap_or("").to_string(),
    }))
}

#[derive(serde::Serialize)]
struct GetRoomAvatarResponse {
    url: String,
}

/// Get room avatar
pub async fn avatar(auth: APIClientAuth, path: web::Path<RoomIDInPath>) -> HttpResult {
    let res = auth
        .send_request(state::get_state_events_for_key::v3::Request::new(
            path.room_id.clone(),
            StateEventType::RoomAvatar,
            String::default(),
        ))
        .await?;

    let avatar_url = res.content.get_field("url")?.unwrap_or("").to_string();

    Ok(HttpResponse::Ok().json(GetRoomAvatarResponse { url: avatar_url }))
}
